@@ -1,5 +1,6 @@
 //This file is part of AcetoneISO. Copyright 2006,2007,2008,2009 Fabrizio Di Marco and Marco Di Antonio  (acetoneiso@gmail.com)
-//
+//Copyright 2010/2011 Marco Di Antonio
+
 //    AcetoneISO is free software: you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
 //    the Free Software Foundation, either version 3 of the License, or
@@ -60,6 +61,7 @@
 #include"erase_cd.h"
 #include"erase_dvd.h"
 #include"burn_iso_2_cd.h"
+#include"burn_iso_2_dvd.h"
 #include"global_functions.h"
 
 
@@ -348,24 +350,23 @@ void acetoneiso::burniso2_cd() {
 int c;
 c = comboBox_2->currentIndex();
 if (c == 0) {
-QFile wodim("/usr/bin/wodim");
+  QFile wodim("/usr/bin/wodim");
   if (!wodim.exists()) { 
     QMessageBox::critical(this, "AcetoneISO::Critical", tr("Unable to find wodim in /usr/bin.\nPlease install wodim package.")); 
     return;
   }
    
-burniso2cd *ecd=new burniso2cd;
-ecd->exec();
+  burniso2cd *ecd=new burniso2cd;
+  ecd->exec();
 }
 else {
-QFile dvd_tools("/usr/bin/growisofs");
+  QFile dvd_tools("/usr/bin/growisofs");
   if (!dvd_tools.exists()) {
     QMessageBox::critical(this, "AcetoneISO::Critical", tr("Unable to find growisofs in /usr/bin.\nPlease install growisofs package.")); 
-    //return;
-  }
- QMessageBox::critical(this, "AcetoneISO::Critical", "da fare");   
-//erasedvd *edvd=new erasedvd;
-//edvd->exec();
+    return;
+  } 
+  burniso2dvd *bdvd=new burniso2dvd;
+  bdvd->exec();
   }  
 }
 
