@@ -68,6 +68,15 @@ while( x < 8 ) {
       Monta( isodamontare, percorsovirtuale );
          while( FUse.waitForFinished() ) { //aspetto che finisca il processo fuse per controllare se è stata montata
          }
+         //check if udf filesystem
+         QFile checkUDF(percorsovirtuale + "/readme.txt");
+	 checkUDF.open(QIODevice::ReadOnly);
+	 QByteArray bcheckUDF = checkUDF.readAll();
+	 QString readUDF = bcheckUDF;
+	 if (readUDF.contains("This disc contains a \"UDF\" ", Qt::CaseInsensitive)  ) {
+	  QMessageBox::warning(this, "AcetoneISO::Warning",tr("This Image appears to have an UDF filesystem.\nTo correctly mount this image, open a terminal as root user and type:") + "\nmount -t auto -o loop \"" + image_with_path + "\" /$path_to_somwhere/ " );
+	 }
+         
          openBrowser( percorsovirtuale, onlyfile, divide, percorsoTemp, image_with_path );
       break;
    }
