@@ -18,7 +18,7 @@
 //il rigo n basta fare: leggiRigo( n, &nomefile) e ci verrà
 //restituita una qstring contenente il rigo n-esimo di nomefile.
 
-QString acetoneiso::leggiRigo( int numeroRigo, QFile *filee )
+QByteArray acetoneiso::leggiRigo( int numeroRigo, QFile *filee )
 {
 QByteArray line = "";    
 for(int i = 0; i < numeroRigo; i++)
